@@ -5,7 +5,11 @@ from bgesdk.error import APIError
 from bgesdk.management import constants
 from bgesdk.management.command import BaseCommand
 from bgesdk.management.utils import (
-    get_active_project, config_get, get_config_path, get_config_parser
+    get_active_project,
+    config_get,
+    get_config_path,
+    get_config_parser,
+    output
 )
 
 
@@ -28,13 +32,13 @@ class Command(BaseCommand):
         try:
             token_result = oauth2.get_credentials_token()
         except APIError as e:
-            print('令牌获取出错: {}'.format(e))
+            output('令牌获取出错: {}'.format(e))
             sys.exit(1)
         self._write_token_config(project, token_result)
-        print('令牌内容如下：')
-        print('')
+        output('令牌内容如下：')
+        output('')
         for key in ['access_token', 'token_type', 'expires_in', 'scope']:
-            print('{} = {}'.format(key, token_result[key]))
+            output('{} = {}'.format(key, token_result[key]))
 
     def _write_token_config(self, project, token_result):
         access_token = token_result['access_token']
@@ -52,4 +56,4 @@ class Command(BaseCommand):
         config_parser.set(section_name, 'scope', scope)
         with open(config_path, 'w') as config_file:
             config_parser.write(config_file)
-        print('令牌已保存至：{}'.format(config_path))
+        output('令牌已保存至：{}'.format(config_path))
